@@ -12,8 +12,6 @@ from mmcv.cnn import (ConvModule, DepthwiseSeparableConvModule,
 from torch.nn.modules.batchnorm import _BatchNorm
 
 from easycv.models.registry import BACKBONES
-from easycv.utils.checkpoint import load_checkpoint
-from easycv.utils.logger import get_root_logger
 
 
 def channel_shuffle(x, groups):
@@ -958,24 +956,18 @@ class LiteHRNet(nn.Module):
 
         return nn.Sequential(*modules), in_channels
 
-    def init_weights(self, pretrained=None):
+    def init_weights(self):
         """Initialize the weights in backbone.
 
         Args:
             pretrained (str, optional): Path to pre-trained weights.
                 Defaults to None.
         """
-        if isinstance(pretrained, str):
-            logger = get_root_logger()
-            load_checkpoint(self, pretrained, strict=False, logger=logger)
-        elif pretrained is None:
-            for m in self.modules():
-                if isinstance(m, nn.Conv2d):
-                    normal_init(m, std=0.001)
-                elif isinstance(m, (_BatchNorm, nn.GroupNorm)):
-                    constant_init(m, 1)
-        else:
-            raise TypeError('pretrained must be a str or None')
+        for m in self.modules():
+            if isinstance(m, nn.Conv2d):
+                normal_init(m, std=0.001)
+            elif isinstance(m, (_BatchNorm, nn.GroupNorm)):
+                constant_init(m, 1)
 
     def forward(self, x):
         """Forward function."""
