@@ -5,8 +5,6 @@ r""" This model is taken from the official PyTorch model zoo.
 
 from torch import nn
 
-from easycv.utils.checkpoint import load_checkpoint
-from easycv.utils.logger import get_root_logger
 from ..modelzoo import mobilenetv2 as model_urls
 from ..registry import BACKBONES
 
@@ -153,27 +151,22 @@ class MobileNetV2(nn.Module):
                 nn.Dropout(0.2),
                 nn.Linear(self.last_channel, num_classes),
             )
-        self.pretrained = model_urls[self.__class__.__name__ + '_' +
-                                     str(width_multi)]
+        self.default_pretrained_model_path = model_urls[self.__class__.__name__
+                                                        + '_' +
+                                                        str(width_multi)]
 
-    def init_weights(self, pretrained=None):
-        if isinstance(pretrained, str) or isinstance(pretrained, dict):
-            logger = get_root_logger()
-            load_checkpoint(self, pretrained, strict=False, logger=logger)
-        elif pretrained is None:
-            for m in self.modules():
-                if isinstance(m, nn.Conv2d):
-                    nn.init.kaiming_normal_(m.weight, mode='fan_out')
-                    if m.bias is not None:
-                        nn.init.zeros_(m.bias)
-                elif isinstance(m, nn.BatchNorm2d):
-                    nn.init.ones_(m.weight)
+    def init_weights(self):
+        for m in self.modules():
+            if isinstance(m, nn.Conv2d):
+                nn.init.kaiming_normal_(m.weight, mode='fan_out')
+                if m.bias is not None:
                     nn.init.zeros_(m.bias)
-                elif isinstance(m, nn.Linear):
-                    nn.init.normal_(m.weight, 0, 0.01)
-                    nn.init.zeros_(m.bias)
-        else:
-            raise TypeError('pretrained must be a str or None')
+            elif isinstance(m, nn.BatchNorm2d):
+                nn.init.ones_(m.weight)
+                nn.init.zeros_(m.bias)
+            elif isinstance(m, nn.Linear):
+                nn.init.normal_(m.weight, 0, 0.01)
+                nn.init.zeros_(m.bias)
 
     def forward(self, x):
         x = self.features(x)
