@@ -12,7 +12,6 @@ from easycv.utils.checkpoint import load_checkpoint, save_checkpoint
 
 if LooseVersion(torch.__version__) >= LooseVersion('1.6.0'):
     from torch.cuda import amp
-    from easycv.hooks.optimizer_hook import AMPFP16OptimizerHook
 
 
 class EVRunner(EpochBasedRunner):
@@ -23,7 +22,8 @@ class EVRunner(EpochBasedRunner):
                  optimizer=None,
                  work_dir=None,
                  logger=None,
-                 meta=None):
+                 meta=None,
+                 fp16_enable=False):
         """ Epoch Runner for easycv, add support for oss IO and file sync.
 
         Args:
@@ -42,13 +42,21 @@ class EVRunner(EpochBasedRunner):
             meta (dict | None): A dict records some import information such as
                 environment info and seed, which will be logged in logger hook.
                 Defaults to None.
+            fp16_enable (bool): if use fp16
         """
 
         super().__init__(model, batch_processor, optimizer, work_dir, logger,
                          meta)
         self.data_loader = None
-        self.fp16_enable = False
+        self.fp16_enable = fp16_enable
         self.visualization_buffer = LogBuffer()
+        if self.fp16_enable and LooseVersion(
+                torch.__version__) < LooseVersion('1.6.0'):
+            # convert model to fp16
+            self.model.half()
+            # patch the normalization layers to make it work in fp32 mode
+            from mmcv.runner.fp16_utils import patch_norm_fp32
+            patch_norm_fp32(self.model)
 
     def run_iter(self, data_batch, train_mode, **kwargs):
         """ process for each iteration.
@@ -86,10 +94,11 @@ class EVRunner(EpochBasedRunner):
         self._max_iters = self._max_epochs * len(self.data_loader)
         self.call_hook('before_train_epoch')
         time.sleep(2)  # Prevent possible deadlock during epoch transition
+
         for i, data_batch in enumerate(self.data_loader):
             self._inner_iter = i
             self.call_hook('before_train_iter')
-            # only in amp from pytorch 1.6 or later, we should use amp.autocast
+            # use amp from pytorch 1.6 or later, we should use amp.autocast
             if self.fp16_enable and LooseVersion(
                     torch.__version__) >= LooseVersion('1.6.0'):
                 with amp.autocast():
