@@ -15,7 +15,6 @@ sys.path.append(
         osp.join(os.path.dirname(os.path.dirname(__file__)), '../')))
 
 import time
-import cv2
 import requests
 import torch
 from mmcv.runner import init_dist
@@ -29,19 +28,17 @@ from easycv.models import build_model
 from easycv.utils.collect_env import collect_env
 from easycv.utils.flops_counter import get_model_info
 from easycv.utils.logger import get_root_logger
+from easycv.utils.mmlab_utils import dynamic_adapt_for_mmlab
 from easycv.utils.config_tools import traverse_replace
 from easycv.utils.config_tools import (CONFIG_TEMPLATE_ZOO,
                                        mmcv_config_fromfile, rebuild_config)
-
-# refer to: https://github.com/open-mmlab/mmdetection/pull/6867
-cv2.setNumThreads(0)
+from easycv.utils.setup_env import setup_multi_processes
 
 
 def parse_args():
     parser = argparse.ArgumentParser(description='Train a model')
     parser.add_argument(
         'config', help='train config file path', type=str, default=None)
-    # parser.add_argument('--config', help='train config file path', default="configs/classification/imagenet/r50.py")
     parser.add_argument(
         '--work_dir',
         type=str,
@@ -126,6 +123,9 @@ def main():
         # rebuild config by user config params
         cfg = rebuild_config(cfg, args.user_config_params)
 
+    # set multi-process settings
+    setup_multi_processes(cfg)
+
     # set cudnn_benchmark
     if cfg.get('cudnn_benchmark', False):
         torch.backends.cudnn.benchmark = True
@@ -149,6 +149,9 @@ def main():
     if args.load_from is not None:
         cfg.load_from = args.load_from
 
+    # dynamic adapt mmdet models
+    dynamic_adapt_for_mmlab(cfg)
+
     cfg.gpus = args.gpus
 
     # check memcached package exists
