@@ -5,6 +5,7 @@ import os
 import shutil
 import socket
 import subprocess
+import timeit
 import uuid
 from multiprocessing import Process
 
@@ -156,3 +157,70 @@ def pseudo_dist_init():
     torch.cuda.set_device(0)
     from torch import distributed as dist
     dist.init_process_group(backend='nccl')
+
+
+def computeStats(backend, timings, batch_size=1, model_name='default'):
+    """
+    compute the statistical metric of time and speed
+    """
+    times = np.array(timings)
+    steps = len(times)
+    speeds = batch_size / times
+    time_mean = np.mean(times)
+    time_med = np.median(times)
+    time_99th = np.percentile(times, 99)
+    time_std = np.std(times, ddof=0)
+    speed_mean = np.mean(speeds)
+    speed_med = np.median(speeds)
+
+    msg = ('\n%s =================================\n'
+           'batch size=%d, num iterations=%d\n'
+           '  Median FPS: %.1f, mean: %.1f\n'
+           '  Median latency: %.6f, mean: %.6f, 99th_p: %.6f, std_dev: %.6f\n'
+           ) % (
+               backend,
+               batch_size,
+               steps,
+               speed_med,
+               speed_mean,
+               time_med,
+               time_mean,
+               time_99th,
+               time_std,
+           )
+
+    meas = {
+        'Name': model_name,
+        'Backend': backend,
+        'Median(FPS)': speed_med,
+        'Mean(FPS)': speed_mean,
+        'Median(ms)': time_med,
+        'Mean(ms)': time_mean,
+        '99th_p': time_99th,
+        'std_dev': time_std,
+    }
+
+    return meas
+
+
+@torch.no_grad()
+def benchmark(predictor,
+              input_data_list,
+              backend='BACKEND',
+              batch_size=1,
+              model_name='default',
+              num=200):
+    """
+    evaluate the time and speed of different models
+    """
+
+    timings = []
+    for i in range(num):
+        start_time = timeit.default_timer()
+        output = predictor.predict(input_data_list)[0]
+        torch.cuda.synchronize()
+        end_time = timeit.default_timer()
+        meas_time = end_time - start_time
+        timings.append(meas_time)
+
+    return computeStats(backend, timings, batch_size, model_name)
